@@ -18,4 +18,5 @@ from .core import time  # Scalar
 from .core import type  # Type
 
 # Forms
-from .forms import Form as form
+from .forms import Form as form # Tool - Create Forms
+from .manager import manager # Tool - Querying Manager
