@@ -133,7 +133,7 @@ class FormBase:
 
     def _init_only_once_for_the_whole_class(self, cls):
         """Class __init__ Replacement"""
-        builtin_keys = ["_init_only_once_for_the_whole_class", "_validate", "Method"]
+        builtin_keys = ["_init_only_once_for_the_whole_class", "_validate", "Next"]
         fields = [
             x for x in dir(self) if not x.startswith("__") and x not in builtin_keys
         ]
@@ -250,10 +250,10 @@ class FormBase:
 def run_validator(form, validator):
     """Return Custom Response to the Dataclass"""
     user_input = validator(form.__dict__)
-    if hasattr(validator, "Method"):
-        if hasattr(validator.Method, "run"):
+    if hasattr(validator, "Next"):
+        if hasattr(validator.Next, "run"):
             if user_input.is_valid:
-                user_input.next = validator.Method.run(user_input.data)
+                user_input.next = validator.Next.run(user_input.data)
     form.input = user_input
 
 
